All Classes (py4j-java 0.10.9.7 API)

# All Classes

- All Classes Interface Summary Class Summary Enum Summary Exception Summary
  Class | Description
  --- | ---
  AbstractCommand | Abstract base class for commands.
  ArrayCommand | A ArrayCommand is responsible for handling operations on arrays.
  AuthCommand | The auth command is responsible for checking that the client knows the server's auth secret.
  Base64 | A very fast and memory efficient class to encode and decode to and from BASE64 in full accordance with RFC 2045. On Windows XP sp1 with 1.4.2_04 and later ;), this encoder and decoder is about 10 times faster on small arrays (10 - 1000 bytes) and 2-3 times as fast on larger arrays (10000 - 1000000 bytes) compared to `sun.misc.Encoder()/Decoder()`. On byte arrays the encoder is about 20% faster than Jakarta Commons Base64 Codec for encode and about 50% faster for decoding large arrays.
  CallbackClient | A CallbackClient is responsible for managing communication channels: channels are created as needed (e.g., one per concurrent thread) and are closed after a certain time.
  CallbackConnection | Default implementation of the CommunicationChannel interface using TCP sockets.
  CallCommand | A CallCommand is responsible for parsing a call command and calling the method on the target object.
  ClassLoadingStrategy | Strategy interface to load a class from a fully qualified name.
  ClientServer | This class creates the JavaServer and the PythonClient necessary to communicate with a Python virtual machine with the new threading model.
  ClientServer.ClientServerBuilder | Helper class to make it easier and self-documenting how a `ClientServer` is constructed.
  ClientServerConnection |
  Command | This interface must be implemented by all commands.
  ConstructorCommand | A ConstructorCommand is responsible for calling the constructors of a Java class.
  CurrentThreadClassLoadingStrategy | This class loading strategy uses the current thread's ClassLoader to load a class from a fully qualified name.
  DefaultApplication | Default application that can be used to quickly test Py4J.
  DefaultGatewayServerListener | This class implements a default `GatewayServerListener`.
  DirCommand |
  ExceptionCommand |
  FieldCommand | A FieldCommand is responsible for accessing and setting fields of objects.
  Gateway | A Gateway manages various states: entryPoint, references to objects returned to a Python program, etc.
  GatewayConnection | Manage the connection between a Python program and a Gateway.
  GatewayServer | This class enables Python programs to access a Java program.
  GatewayServer.GatewayServerBuilder | Helper class to make it easier and self-documenting how a `GatewayServer` is constructed.
  GatewayServerListener | A client can implement this listener to be notified of Gateway events.
  HelpPageCommand | A HelpPageCommand is responsible for generating a help page for a Java object or Java class.
  HelpPageGenerator | The HelpPageGenerator generates a help page (a String) for a class or a method.
  JavaServer | This class extends GatewayServer by implementing a new threading model: a thread always use the same connection to the other side so callbacks are executed in the calling thread.
  JVMView | A JVM view keeps track of imports and import searches.
  JVMViewCommand | A JVMViewCommand is responsible for managing JVM views: creating views, adding imports, searching for fully qualified names.
  ListCommand | A ListCommand is responsible for handling operations on lists (e.g., slicing).
  LRUCache<K,​V> | Implementation of a Least Recently Used cache.
  MemoryCommand | The MemoryCommand is responsible for handling garbage collection requests from the Python side, i.e., when a java object is no longer used by the Python program.
  MethodDescriptor | A MethodDescriptor wraps the signature of a method (name, container, parameters).
  MethodInvoker | A MethodInvoker translates a call made in a Python Program into a call to a Java method.
  NetworkUtil | Utility class used to perform network operations.
  Protocol | This class defines the protocol used to communicate between two virtual machines (e.g., Python and Java).
  Py4JAuthenticationException |
  Py4JClass | Model of a Java class used to create a help page.
  Py4JClientConnection |
  Py4JException | Exception raised when an error is encountered while using Py4J.
  Py4JField | Model of a Java field used to create a help page.
  Py4JJavaException | Exception raised when an exception is thrown in the client code.
  Py4JJavaServer | Interface that describes the operations a server must support to receive requests from the Python side.
  Py4JMember | Model of a Java member (class, method, or field) used to create a help page.
  Py4JMethod | Model of a Java method used to create a help page.
  Py4JNetworkException | Exception raised when a network error is encountered while using Py4J.
  Py4JNetworkException.ErrorTime |
  Py4JPythonClient | Interface that describes the operations a client must support to make requests to the Python side.
  Py4JPythonClientPerThread |
  Py4JServerConnection |
  PythonClient | Subclass of CallbackClient that implements the new threading model, ensuring that each thread uses its own connection.
  PythonProxyHandler | A PythonProxyHandler is used in place of a Python object.
  ReflectionCommand | The ReflectionCommand is responsible for accessing packages, classes, and static members.
  ReflectionEngine | The reflection engine is responsible for accessing the classes, the instances and members in a JVM.
  ReflectionShim |
  ReflectionUtil | Global utility to load classes and perform general reflection operations that can be customized by Strategy classes.
  ReturnObject | A ReturnObject wraps a value returned by a method.
  RootClassLoadingStrategy | This class loading strategy just uses the class current class loader to load a class from a fully qualified name.
  ShutdownGatewayServerCommand | The ShutdownGatewayServerCommand is responsible for shutting down the GatewayServer.
  StreamCommand | A `StreamCommand` is like a `CallCommand`, but returns the value directly.
  StringUtil | String utility class providing operations to escape and unescape new lines.
  TypeConverter | A TypeConverter converts a Python type into a Java Type.
  TypeUtil | This class is responsible for the type conversion between Python types and Java types.